@@ -7,9 +7,12 @@ cmake -D CMAKE_INSTALL_PREFIX=$PREFIX \
       -D ENABLE_HDF4=ON \
       -D ENABLE_NETCDF_4=ON \
       -D BUILD_SHARED_LIBS=OFF \
-      -D ENABLE_TESTS=ON \
+      -D ENABLE_TESTS=OFF \
       -D BUILD_UTILITIES=ON \
       -D ENABLE_DOXYGEN=OFF \
+      -D ENABLE_LOGGING=ON \
+      -D CURL_INCLUDE_DIR=$PREFIX/include \
+      -D CURL_LIBRARY=$PREFIX/lib/libcurl${SHLIB_EXT} \
       $SRC_DIR
 make
 # ctest  # Run only for the shared lib build to save time.
@@ -23,9 +26,12 @@ cmake -D CMAKE_INSTALL_PREFIX=$PREFIX \
       -D ENABLE_HDF4=ON \
       -D ENABLE_NETCDF_4=ON \
       -D BUILD_SHARED_LIBS=ON \
-      -D ENABLE_TESTS=ON \
+      -D ENABLE_TESTS=OFF \
       -D BUILD_UTILITIES=ON \
       -D ENABLE_DOXYGEN=OFF \
+      -D ENABLE_LOGGING=ON \
+      -D CURL_INCLUDE_DIR=$PREFIX/include \
+      -D CURL_LIBRARY=$PREFIX/lib/libcurl${SHLIB_EXT} \
       $SRC_DIR
 make
 ctest
